@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 module Icalendar
 
   class Calendar < Component
@@ -31,6 +33,42 @@ module Icalendar
 
     def publish
       self.ip_method = 'PUBLISH'
+      self
+    end
+
+    def request
+      self.ip_method = 'REQUEST'
+      self
+    end
+
+    def reply
+      self.ip_method = 'REPLY'
+      self
+    end
+
+    def add
+      self.ip_method = 'ADD'
+      self
+    end
+
+    def cancel
+      self.ip_method = 'CANCEL'
+      self
+    end
+
+    def refresh
+      self.ip_method = 'REFRESH'
+      self
+    end
+
+    def counter
+      self.ip_method = 'COUNTER'
+      self
+    end
+
+    def decline_counter
+      self.ip_method = 'DECLINECOUNTER'
+      self
     end
 
   end
