@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 module Icalendar
 
   class Event < Component
@@ -24,7 +26,7 @@ module Icalendar
     optional_single_property :status
     optional_single_property :summary
     optional_single_property :transp
-    optional_single_property :url, Icalendar::Values::Uri
+    optional_single_property :url, Icalendar::Values::Uri, true
     optional_single_property :recurrence_id, Icalendar::Values::DateTime
 
     optional_property :rrule, Icalendar::Values::Recur, true
