@@ -197,7 +197,7 @@ module Icalendar
         value = parts[:value]
       else
         parts = BAD_LINE_REGEX.match(input) unless strict?
-        parts or fail "Invalid iCalendar input line: #{input}"
+        parts or fail ParseError, "Invalid iCalendar input line: #{input}"
         # Non-strict and bad line so use a value of empty string
         value = ''
       end
@@ -211,7 +211,7 @@ module Icalendar
             param_value = param_value.gsub(PVALUE_GSUB_REGEX, '')
             params[param_name] << param_value
             if param_name == 'tzid'
-              params['x-tz-info'] = timezone_store.retrieve param_value
+              params['x-tz-store'] = timezone_store
             end
           end
         end
@@ -227,5 +227,8 @@ module Icalendar
         value: value
       }
     end
+
+    class ParseError < RuntimeError
+    end
   end
 end
