@@ -10,7 +10,7 @@ module Icalendar
 
       def initialize(value, params = {})
         params.delete 'tzid'
-        params.delete 'x-tz-info'
+        params.delete 'x-tz-store'
         if value.is_a? String
           begin
             parsed_date = ::Date.strptime(value, FORMAT)
