@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 module Icalendar
   module Values
     class Text < Value
@@ -9,12 +11,14 @@ module Icalendar
         super value, params
       end
 
+      VALUE_ICAL_CARRIAGE_RETURN_GSUB_REGEX = /\r?\n/.freeze
+
       def value_ical
         value.dup.tap do |v|
           v.gsub!('\\') { '\\\\' }
           v.gsub!(';', '\;')
           v.gsub!(',', '\,')
-          v.gsub!(/\r?\n/, '\n')
+          v.gsub!(VALUE_ICAL_CARRIAGE_RETURN_GSUB_REGEX, '\n')
         end
       end
     end
